@@ -20,6 +20,7 @@ pub use delay_parser::DelayParser;
 pub use pre_parser::PreParser;
 pub use simple_parser::SimpleParser;
 pub use state::ParserState;
+use ustr::Ustr;
 
 #[derive(Debug)]
 pub struct OptValueKeeper {
@@ -77,5 +78,7 @@ pub trait Parser: Debug {
 
     fn callback_iter(&self) -> HashMapIter<'_, Uid, RefCell<OptCallback>>;
 
+    fn get_noa(&self) -> &[Ustr];
+
     fn reset(&mut self);
 }
